@@ -53,9 +53,7 @@
 #include "dmxcb.h"
 #include "dmxprop.h"
 #include "dmxstat.h"
-#ifdef RENDER
 #include "dmxpict.h"
-#endif
 
 #include <X11/Xos.h>                /* For gettimeofday */
 #include "dixstruct.h"
@@ -71,12 +69,6 @@
 #include "dmx_glxvisuals.h"
 #include <X11/extensions/Xext.h>
 #include <X11/extensions/extutil.h>
-
-extern void GlxSetVisualConfigs(
-    int               nconfigs,
-    __GLXvisualConfig *configs,
-    void              **configprivs
-);
 #endif /* GLXEXT */
 
 /* Global variables available to all Xserver/hw/dmx routines. */
@@ -406,7 +398,7 @@ Bool dmxGetVisualInfo(DMXScreenInfo *dmxScreen)
         dmxLogVisual(dmxScreen, &dmxScreen->beVisuals[i],
                      (i == dmxScreen->beDefVisualIndex));
 
-    return (dmxScreen->beDefVisualIndex >= 0);
+    return dmxScreen->beDefVisualIndex >= 0;
 }
 
 void dmxGetColormaps(DMXScreenInfo *dmxScreen)
@@ -414,7 +406,7 @@ void dmxGetColormaps(DMXScreenInfo *dmxScreen)
     int i;
 
     dmxScreen->beNumDefColormaps = dmxScreen->beNumVisuals;
-    dmxScreen->beDefColormaps = xalloc(dmxScreen->beNumDefColormaps *
+    dmxScreen->beDefColormaps = malloc(dmxScreen->beNumDefColormaps *
 				       sizeof(*dmxScreen->beDefColormaps));
 
     for (i = 0; i < dmxScreen->beNumDefColormaps; i++)
@@ -608,8 +600,8 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
             dmxScreens[i].stat = NULL;
         }
         for (i = 0; i < dmxNumInputs; i++) dmxInputFree(&dmxInputs[i]);
-        if (dmxScreens) free(dmxScreens);
-        if (dmxInputs)  free(dmxInputs);
+        free(dmxScreens);
+        free(dmxInputs);
         dmxScreens    = NULL;
         dmxInputs     = NULL;
         dmxNumScreens = 0;
@@ -740,7 +732,7 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
 		nconfigs = dmxScreen->numGlxVisuals;
 	    }
 
-	    configprivs = xalloc(nconfigs * sizeof(dmxGlxVisualPrivate*));
+	    configprivs = malloc(nconfigs * sizeof(dmxGlxVisualPrivate*));
 
 	    if (configs != NULL && configprivs != NULL) {
 
@@ -750,7 +742,7 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
 		for (i = 0; i < nconfigs; i++) {
 
 		    configprivs[i] = (dmxGlxVisualPrivate *)
-			xalloc(sizeof(dmxGlxVisualPrivate));
+			malloc(sizeof(dmxGlxVisualPrivate));
 		    configprivs[i]->x_visual_depth = 0;
 		    configprivs[i]->x_visual_class = 0;
 
@@ -770,9 +762,6 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
 		    }
 		}
 
-		/* Hand out the glx configs to glx extension */
-		GlxSetVisualConfigs(nconfigs, configs, (void**)configprivs);
-
                 XFlush(dmxScreen->beDisplay);
 	    }
 	}
@@ -795,11 +784,9 @@ void InitOutput(ScreenInfo *pScreenInfo, int argc, char *argv[])
      */
     dmxInitFonts();
 
-#ifdef RENDER
     /* Initialize the render extension */
     if (!noRenderExtension)
 	dmxInitRender();
-#endif
 
     /* Initialized things that need timer hooks */
     dmxStatInit();
@@ -820,11 +807,11 @@ static void dmxSetDefaultFontPath(char *fp)
 	int len;
 
 	len = strlen(dmxFontPath);
-	dmxFontPath = xrealloc(dmxFontPath, len+fplen+1);
+	dmxFontPath = realloc(dmxFontPath, len+fplen+1);
 	dmxFontPath[len] = ',';
 	strncpy(&dmxFontPath[len+1], fp, fplen);
     } else {
-	dmxFontPath = xalloc(fplen);
+	dmxFontPath = malloc(fplen);
 	strncpy(dmxFontPath, fp, fplen);
     }
 
@@ -834,7 +821,7 @@ static void dmxSetDefaultFontPath(char *fp)
 /** This function is called in Xserver/os/utils.c from \a AbortServer().
  * We must ensure that backend and console state is restored in the
  * event the server shutdown wasn't clean. */
-void AbortDDX(void)
+void AbortDDX(enum ExitCode error)
 {
     int i;
 
@@ -846,12 +833,18 @@ void AbortDDX(void)
     }
 }
 
+#ifdef DDXBEFORERESET
+void ddxBeforeReset(void)
+{
+}
+#endif
+
 /** This function is called in Xserver/dix/main.c from \a main() when
  * dispatchException & DE_TERMINATE (which is the only way to exit the
  * main loop without an interruption. */
-void ddxGiveUp(void)
+void ddxGiveUp(enum ExitCode error)
 {
-    AbortDDX();
+    AbortDDX(error);
 }
 
 /** This function is called in Xserver/os/osinit.c from \a OsInit(). */
