@@ -43,6 +43,7 @@
 #ifndef PROJECT_NAME
 #  define PROJECT_NAME		"Cygwin/X"
 #endif
+#define EXECUTABLE_NAME         "XWin"
 #define WINDOW_CLASS		"cygwin/x"
 #define WINDOW_TITLE		PROJECT_NAME ":%s.%d"
 #define WINDOW_TITLE_XDMCP	"%s:%s.%d"
@@ -78,6 +79,10 @@ typedef struct
   HWND			hWnd;
   winPrivScreenPtr	pScreenPriv;
   Bool			fXKilled;
+  HDWP                  hDwp;
+#ifdef XWIN_GLX_WINDOWS
+  Bool			fWglUsed;
+#endif
 
   /* Privates used by primary fb DirectDraw server */
   LPDDSURFACEDESC	pddsdPrimary;
